## Copyright (C) 2017 Pantxo Diribarne
## 
## This program is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*- 
## @deftypefn {} {@var{retval} =} __datacursor_menu__ ()
## Undocumented internal function.
## @end deftypefn

## Author: Pantxo Diribarne <pantxo@gre046552>
## Created: 2017-02-10
## Modified by R. Baudin, 2017-05-10

function hm = __datacursor_menu__ ()
  
  hf = get (0, "currentfigure");
  
  if (isempty (hf))
    error ("__datacursor_menu__: no current figure");
  endif
  
  # Don't add menu if custom property 'datamenu' already exist
  if (isprop(hf, "datamenu") == 0)
    addproperty("datamenu", hf, "boolean",true); # Add custom property 'datamenu'
    hm = uimenu ("label", "&Data");
    htmp = hm;  
    htmp = uimenu (hm, "label", "New data cursor", "callback", {@update_new, htmp});
    htmp = uimenu (hm, "label", "Show/hide data cursor(s)", "callback", @update_show);
    htmp = uimenu (hm, "label", "Get cursor(s) data", "callback", @data_dlg);
  endif

endfunction

function update_new (hmenu, e, hshow)
  __datacursor__ (gcbf);
  update_show (hshow, [], true);
endfunction
      
function update_show (hmenu, e, on = [])
  hc = getappdata (gcbf, "__datacursor__");
  if (! isempty (hc))
    if (isempty (on))
      on = ifelse (all (strcmp (get (hc, "visible"), "on")), "off", "on");
    endif
    set (hc, "visible", on)
    set (hmenu, "checked", on)
  endif
endfunction

function data_dlg (hm, e)
  pos = get (gcbf, "position");
  hc = getappdata (gcbf, "__datacursor__");
  nm = inputdlg ({"Name of the variable:"}, "Export data", 1, {"cursor_data"});
  if (! isempty (nm))
    for ii = 1:numel (hc)
      xy = get (hc(ii), "userdata");
      evalin ("base", sprintf ("%s.('%s') = [%16.16f; %16.16f];", ...
                               nm{1}, ["cursor" num2str(ii)], xy(1), xy(2)));
    endfor
  endif
endfunction
